==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/igr-stacked-column-series.js <==
import { __extends } from "tslib";
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedColumnSeries } from "./StackedColumnSeries";
/**
 * Represents a IgxDataChartComponent stacked column series.
*/
var IgrStackedColumnSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStackedColumnSeries, _super);
    function IgrStackedColumnSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedColumnSeries.prototype.createImplementation = function () {
        return new StackedColumnSeries();
    };
    Object.defineProperty(IgrStackedColumnSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "isColumn", {
        /**
         * Gets whether the current series shows a column shape.
        */
        get: function () {
            return this.i.ex;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.fj;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.abl;
        },
        set: function (v) {
            this.i.abl = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.abm;
        },
        set: function (v) {
            this.i.abm = +v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrStackedColumnSeries.prototype.getItemSpan = function () {
        var iv = this.i.iu();
        return (iv);
    };
    return IgrStackedColumnSeries;
}(IgrHorizontalStackedSeriesBase));
export { IgrStackedColumnSeries };

==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/igr-stacked-column-series.js <==
import { __extends } from "tslib";
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedColumnSeries } from "./StackedColumnSeries";
/**
 * Represents a IgxDataChartComponent stacked column series.
*/
var IgrStackedColumnSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStackedColumnSeries, _super);
    function IgrStackedColumnSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedColumnSeries.prototype.createImplementation = function () {
        return new StackedColumnSeries();
    };
    Object.defineProperty(IgrStackedColumnSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "isColumn", {
        /**
         * Gets whether the current series shows a column shape.
        */
        get: function () {
            return this.i.e1;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.fm;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.ab7;
        },
        set: function (v) {
            this.i.ab7 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.ab8;
        },
        set: function (v) {
            this.i.ab8 = +v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrStackedColumnSeries.prototype.getItemSpan = function () {
        var iv = this.i.ix();
        return (iv);
    };
    return IgrStackedColumnSeries;
}(IgrHorizontalStackedSeriesBase));
export { IgrStackedColumnSeries };
